@@ -15,7 +15,7 @@
 #include <QList>
 
 #include <QStandardPaths>
-
+using namespace Qt::Literals::StringLiterals;
 using namespace Akonadi::Search::PIM;
 
 class Akonadi::Search::PIM::CollectionQueryPrivate
@@ -31,10 +31,9 @@ public:
 };
 
 CollectionQuery::CollectionQuery()
-    : Query()
-    , d(new CollectionQueryPrivate)
+    : d(new CollectionQueryPrivate)
 {
-    d->databaseDir = defaultLocation(QStringLiteral("collections"));
+    d->databaseDir = defaultLocation(u"collections"_s);
     d->limit = 0;
 }
 
