@@ -188,8 +188,8 @@ Xapian::Query XapianQueryParser::parseQuery(const QString &text, const QString &
                 position++;
                 if (inDoubleQuotes || inSingleQuotes || inPhrase) {
                     const QByteArray arr = term.toUtf8();
-                    const std::string str(arr.constData(), arr.length());
-                    phraseQueries << Xapian::Query(str, 1, position);
+                    const std::string strString(arr.constData(), arr.length());
+                    phraseQueries << Xapian::Query(strString, 1, position);
                 } else {
                     if (m_autoExpand) {
                         queries << makeQuery(term, position, m_db);
