@@ -6,8 +6,9 @@
  */
 
 #include "xapiantermgenerator.h"
+using namespace Qt::Literals::StringLiterals;
 
-#include "akonadi_search_xapian_debug.h"
+#include <QStringList>
 #include <QTextBoundaryFinder>
 
 using namespace Akonadi::Search;
@@ -62,7 +63,7 @@ QStringList XapianTermGenerator::termList(const QString &text)
             }
 
             str = cleanString.normalized(QString::NormalizationForm_KC);
-            list << str.split(QLatin1Char('_'), Qt::SkipEmptyParts);
+            list << str.split(u'_', Qt::SkipEmptyParts);
         }
     }
 
